package cn.minestar.agriculture.service.impl;

import java.util.List;

import cn.minestar.agriculture.entity.WxMiniBrowsingHistory;
import cn.minestar.agriculture.mapper.WxMiniBrowsingHistoryMapper;
import cn.minestar.agriculture.service.IWxMiniBrowsingHistoryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author www.minestar.cn/
 * @date 2021-08-10
 */
@Service
public class WxMiniBrowsingHistoryServiceImpl implements IWxMiniBrowsingHistoryService
{
    @Autowired
    private WxMiniBrowsingHistoryMapper wxMiniBrowsingHistoryMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    @Override
    public WxMiniBrowsingHistory selectWxMiniBrowsingHistoryById(Long id)
    {
        return wxMiniBrowsingHistoryMapper.selectWxMiniBrowsingHistoryById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param wxMiniBrowsingHistory 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<WxMiniBrowsingHistory> selectWxMiniBrowsingHistoryList(WxMiniBrowsingHistory wxMiniBrowsingHistory)
    {
        return wxMiniBrowsingHistoryMapper.selectWxMiniBrowsingHistoryList(wxMiniBrowsingHistory);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param wxMiniBrowsingHistory 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertWxMiniBrowsingHistory(WxMiniBrowsingHistory wxMiniBrowsingHistory)
    {
        return wxMiniBrowsingHistoryMapper.insertWxMiniBrowsingHistory(wxMiniBrowsingHistory);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param wxMiniBrowsingHistory 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateWxMiniBrowsingHistory(WxMiniBrowsingHistory wxMiniBrowsingHistory)
    {
        return wxMiniBrowsingHistoryMapper.updateWxMiniBrowsingHistory(wxMiniBrowsingHistory);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteWxMiniBrowsingHistoryByIds(Long[] ids)
    {
        return wxMiniBrowsingHistoryMapper.deleteWxMiniBrowsingHistoryByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    @Override
    public int deleteWxMiniBrowsingHistoryById(Long id)
    {
        return wxMiniBrowsingHistoryMapper.deleteWxMiniBrowsingHistoryById(id);
    }
}
